@@ -15,6 +15,7 @@
 import logging
 import logging.handlers
 import os
+import tempfile
 import uuid
 
 import fixtures
@@ -44,6 +45,19 @@ class RootwrapLoaderTestCase(testtools.TestCase):
             self.assertEqual(["/fake/privsep-helper", "--context", "foo"],
                              filtermatch.get_command(privsep))
 
+    def test_strict_switched_off_in_configparser(self):
+        temp_dir = self.useFixture(fixtures.TempDir()).path
+        os.mkdir(os.path.join(temp_dir, 'nested'))
+        temp_file = os.path.join(temp_dir, 'test.conf')
+        f = open(temp_file, 'w')
+        f.write("""[Filters]
+privsep: PathFilter, privsep-helper, root
+privsep: PathFilter, privsep-helper, root
+""")
+        f.close()
+        filterlist = wrapper.load_filters([temp_dir])
+        self.assertIsNotNone(filterlist)
+
 
 class RootwrapTestCase(testtools.TestCase):
     if os.path.exists('/sbin/ip'):
@@ -156,7 +170,7 @@ class RootwrapTestCase(testtools.TestCase):
         # check that environment variables are set
         self.assertEqual('/some/thing', env.get('A'))
         self.assertEqual('somethingelse', env.get('B'))
-        self.assertFalse('sleep' in env.keys())
+        self.assertNotIn('sleep', env.keys())
 
     def test_EnvFilter_without_leading_env(self):
         envset = ['A=/some/thing', 'B=somethingelse']
@@ -175,7 +189,7 @@ class RootwrapTestCase(testtools.TestCase):
         # check that environment variables are set
         self.assertEqual('/some/thing', env.get('A'))
         self.assertEqual('somethingelse', env.get('B'))
-        self.assertFalse('sleep' in env.keys())
+        self.assertNotIn('sleep', env.keys())
 
     def test_KillFilter(self):
         if not os.path.exists("/proc/%d" % os.getpid()):
@@ -254,33 +268,42 @@ class RootwrapTestCase(testtools.TestCase):
                 exists.side_effect = fake_exists
                 self.assertTrue(f.match(usercmd))
 
-    def test_KillFilter_upgraded_exe(self):
+    @mock.patch('os.readlink')
+    @mock.patch('os.path.isfile')
+    def test_KillFilter_upgraded_exe(self, mock_isfile, mock_readlink):
         """Makes sure upgraded exe's are killed correctly."""
         f = filters.KillFilter("root", "/bin/commandddddd")
         command = "/bin/commandddddd"
         usercmd = ['kill', 1234]
-        with mock.patch('os.readlink') as readlink:
-            readlink.return_value = command + '\0\05190bfb2 (deleted)'
-            with mock.patch('os.path.isfile') as exists:
-                def fake_exists(path):
-                    return path == command
-                exists.side_effect = fake_exists
-                self.assertTrue(f.match(usercmd))
 
-    def test_KillFilter_renamed_exe(self):
+        def fake_exists(path):
+            return path == command
+
+        mock_readlink.return_value = command + '\0\05190bfb2 (deleted)'
+        mock_isfile.side_effect = fake_exists
+        self.assertTrue(f.match(usercmd))
+
+    @mock.patch('os.readlink')
+    @mock.patch('os.path.isfile')
+    @mock.patch('os.path.exists')
+    @mock.patch('os.access')
+    def test_KillFilter_renamed_exe(self, mock_access, mock_exists,
+                                    mock_isfile, mock_readlink):
         """Makes sure renamed exe's are killed correctly."""
         command = "/bin/commandddddd"
         f = filters.KillFilter("root", command)
         usercmd = ['kill', 1234]
-        with mock.patch('os.readlink') as readlink:
-            readlink.return_value = command + ';90bfb2 (deleted)'
-            m = mock.mock_open(read_data=command)
-            with mock.patch("six.moves.builtins.open", m, create=True):
-                with mock.patch('os.path.isfile') as exists:
-                    def fake_exists(path):
-                        return path == command
-                    exists.side_effect = fake_exists
-                    self.assertTrue(f.match(usercmd))
+
+        def fake_os_func(path, *args):
+            return path == command
+
+        mock_readlink.return_value = command + ';90bfb2 (deleted)'
+        m = mock.mock_open(read_data=command)
+        with mock.patch("six.moves.builtins.open", m, create=True):
+            mock_isfile.side_effect = fake_os_func
+            mock_exists.side_effect = fake_os_func
+            mock_access.side_effect = fake_os_func
+            self.assertTrue(f.match(usercmd))
 
     def test_ReadFileFilter(self):
         goodfn = '/good/file.name'
@@ -305,6 +328,8 @@ class RootwrapTestCase(testtools.TestCase):
         self.assertFalse(f.match(['ip', 'netns', 'exec']))
         self.assertFalse(f.match(['ip', '-s', 'netns', 'exec']))
         self.assertFalse(f.match(['ip', '-l', '42', 'netns', 'exec']))
+        self.assertFalse(f.match(['ip', 'net', 'exec', 'foo']))
+        self.assertFalse(f.match(['ip', 'netns', 'e', 'foo']))
 
     def _test_IpFilter_netns_helper(self, action):
         f = filters.IpFilter(self._ip, 'root')
@@ -323,10 +348,19 @@ class RootwrapTestCase(testtools.TestCase):
         f = filters.IpNetnsExecFilter(self._ip, 'root')
         self.assertTrue(
             f.match(['ip', 'netns', 'exec', 'foo', 'ip', 'link', 'list']))
+        self.assertTrue(f.match(['ip', 'net', 'exec', 'foo', 'bar']))
+        self.assertTrue(f.match(['ip', 'netn', 'e', 'foo', 'bar']))
+        self.assertTrue(f.match(['ip', 'net', 'e', 'foo', 'bar']))
+        self.assertTrue(f.match(['ip', 'net', 'exe', 'foo', 'bar']))
 
     def test_IpNetnsExecFilter_nomatch(self):
         f = filters.IpNetnsExecFilter(self._ip, 'root')
         self.assertFalse(f.match(['ip', 'link', 'list']))
+        self.assertFalse(f.match(['ip', 'foo', 'bar', 'netns']))
+        self.assertFalse(f.match(['ip', '-s', 'netns', 'exec']))
+        self.assertFalse(f.match(['ip', '-l', '42', 'netns', 'exec']))
+        self.assertFalse(f.match(['ip', 'netns exec', 'foo', 'bar', 'baz']))
+        self.assertFalse(f.match([]))
 
         # verify that at least a NS is given
         self.assertFalse(f.match(['ip', 'netns', 'exec']))
@@ -489,7 +523,8 @@ class PathFilterTestCase(testtools.TestCase):
     def setUp(self):
         super(PathFilterTestCase, self).setUp()
 
-        tmpdir = fixtures.TempDir('/tmp')
+        self.tmp_root_dir = tempfile.mkdtemp()
+        tmpdir = fixtures.TempDir(self.tmp_root_dir)
         self.useFixture(tmpdir)
 
         self.f = filters.PathFilter('/bin/chown', 'root', 'nova', tmpdir.path)
@@ -497,7 +532,7 @@ class PathFilterTestCase(testtools.TestCase):
         gen_name = lambda: str(uuid.uuid4())
 
         self.SIMPLE_FILE_WITHIN_DIR = os.path.join(tmpdir.path, 'some')
-        self.SIMPLE_FILE_OUTSIDE_DIR = os.path.join('/tmp', 'some')
+        self.SIMPLE_FILE_OUTSIDE_DIR = os.path.join(self.tmp_root_dir, 'some')
         self.TRAVERSAL_WITHIN_DIR = os.path.join(tmpdir.path, 'a', '..',
                                                  'some')
         self.TRAVERSAL_OUTSIDE_DIR = os.path.join(tmpdir.path, '..', 'some')
@@ -516,7 +551,8 @@ class PathFilterTestCase(testtools.TestCase):
         os.symlink(os.path.join(tmpdir.path, 'a'), self.SYMLINK_WITHIN_DIR)
 
         self.SYMLINK_OUTSIDE_DIR = os.path.join(tmpdir.path, gen_name())
-        os.symlink(os.path.join('/tmp', 'some_file'), self.SYMLINK_OUTSIDE_DIR)
+        os.symlink(os.path.join(self.tmp_root_dir, 'some_file'),
+                   self.SYMLINK_OUTSIDE_DIR)
 
     def test_empty_args(self):
         self.assertFalse(self.f.match([]))
@@ -529,12 +565,13 @@ class PathFilterTestCase(testtools.TestCase):
         self.assertTrue(f.match(args))
 
     def test_argument_equality_constraint(self):
-        f = filters.PathFilter('/bin/chown', 'root', 'nova', '/tmp/spam/eggs')
+        temp_file_path = os.path.join(self.tmp_root_dir, 'spam/eggs')
+        f = filters.PathFilter('/bin/chown', 'root', 'nova', temp_file_path)
 
-        args = ['chown', 'nova', '/tmp/spam/eggs']
+        args = ['chown', 'nova', temp_file_path]
         self.assertTrue(f.match(args))
 
-        args = ['chown', 'quantum', '/tmp/spam/eggs']
+        args = ['chown', 'quantum', temp_file_path]
         self.assertFalse(f.match(args))
 
     def test_wrong_arguments_number(self):
@@ -631,6 +668,7 @@ class DaemonCleanupTestCase(testtools.TestCase):
     @mock.patch('tempfile.mkdtemp')
     @mock.patch('multiprocessing.managers.BaseManager.get_server',
                 side_effect=DaemonCleanupException)
-    def test_daemon_no_cleanup_for_uninitialized_server(self, gs, *args):
+    def test_daemon_no_cleanup_for_uninitialized_server(self, gs, mkd, *args):
+        mkd.return_value = '/just_dir/123'
         self.assertRaises(DaemonCleanupException, daemon.daemon_start,
                           config=None, filters=None)
